<?php

namespace Drupal\environment_indicator_header\EventSubscriber;

use Drupal\environment_indicator_header\Service\CurrentReleaseService;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\Event\ResponseEvent;
use Symfony\Component\HttpKernel\KernelEvents;

/**
 * Event subscriber to add header.
 */
class ReleaseHeaderSubscriber implements EventSubscriberInterface {

  /**
   * The current release service.
   *
   * @var \Drupal\environment_indicator_header\Service\CurrentReleaseService
   */
  protected $currentReleaseService;

  /**
   * The event subscriber constructor.
   *
   * @param \Drupal\environment_indicator_header\Service\CurrentReleaseService $currentReleaseService
   *   The current release service.
   */
  public function __construct(CurrentReleaseService $currentReleaseService) {
    $this->currentReleaseService = $currentReleaseService;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    $events[KernelEvents::RESPONSE][] = ['onResponse'];
    return $events;
  }

  /**
   * Add header to the event response.
   *
   * @param \Symfony\Component\HttpKernel\Event\ResponseEvent $event
   *   The event.
   */
  public function onResponse(ResponseEvent $event) {
    $response = $event->getResponse();
    $current_release = $this->currentReleaseService->getCurrentRelease();
    if ($current_release) {
      $response->headers->set('Release', $current_release);
    }
  }

}
